@@ -13,6 +13,8 @@ class Expression(ToJSONPath):
         return isinstance(other, self.__class__) and (self.__dict__ == other.__dict__)
 
     @abstractmethod
-    def evaluate(self, root_value: object, current_value: object) -> bool:  # pragma: no cover abstract method
+    def evaluate(
+        self, root_value: object, current_value: object
+    ) -> bool:  # pragma: no cover abstract method
         """Abstract method to evaluate the expression."""
         raise NotImplementedError()
