@@ -18,15 +18,16 @@ class RecursiveDescentNode(Node):
 
     def __jsonpath__(self) -> Generator[str, None, None]:
         """Dump the string for the previous node."""
-        yield '..'
+        yield ".."
         for next_node_token in self.next_node.__jsonpath__():
             yield next_node_token
 
-    def match(self, root_value: object, current_value: object) -> Generator[MatchData, None, None]:
+    def match(
+        self, root_value: object, current_value: object
+    ) -> Generator[MatchData, None, None]:
         """Match the root value with the current value."""
         # NOTE Depth-first
         return itertools.chain(
             self.next_node.match(root_value, current_value),
-            SubscriptNode(self, [WildcardSubscript()]).match(
-                root_value, current_value)
+            SubscriptNode(self, [WildcardSubscript()]).match(root_value, current_value),
         )
