@@ -22,14 +22,28 @@ class ArrayIndexSubscript(Subscript):
         """Dump the json index when rendering jsonpath."""
         yield json.dumps(self.index)
 
-    def match(self, root_value: object, current_value: object) -> Generator[MatchData, None, None]:
+    def match(
+        self, root_value: object, current_value: object
+    ) -> Generator[MatchData, None, None]:
         """Match the root value against the current value."""
         if isinstance(current_value, Sequence) and not isinstance(current_value, str):
             if self.index < 0:
                 new_index = self.index + len(current_value)
 
                 if 0 <= new_index < len(current_value):
-                    return [MatchData(SubscriptNode(TerminalNode(), [self]), root_value, current_value[new_index])]
+                    return [
+                        MatchData(
+                            SubscriptNode(TerminalNode(), [self]),
+                            root_value,
+                            current_value[new_index],
+                        )
+                    ]
             elif self.index < len(current_value):
-                return [MatchData(SubscriptNode(TerminalNode(), [self]), root_value, current_value[self.index])]
+                return [
+                    MatchData(
+                        SubscriptNode(TerminalNode(), [self]),
+                        root_value,
+                        current_value[self.index],
+                    )
+                ]
         return []
